@@ -5,7 +5,7 @@ class EthashRecipe(PythonRecipe):
 
     url = 'https://github.com/ethereum/ethash/archive/master.zip'
 
-    depends = ['python2', 'setuptools']
+    depends = ['setuptools']
 
 
 recipe = EthashRecipe()
